@@ -16,7 +16,7 @@ def cli():
 @cli.command()
 @click.option('-d', '--directory', type=click.Path(exists=True))
 @click.option('-c', '--config-file', type=click.File())
-@click.option('-p', '--params', default="{}")
+@click.option('-p', '--params', default=[], multiple=True)
 @click.option('-t', '--tags', default="{}")
 @click.option('-r', '--replicas', default="{}")
 @click.option('-s', '--secrets', default="{}")
@@ -35,15 +35,19 @@ def apply(stackl_context, directory, config_file, params, tags, secrets,
 
 def apply_stack_instance(config_file, params, tags, secrets, service_params,
                          replicas, stackl_context, instance_name):
+    final_params = {}
+    for item in params:
+        final_params = {**final_params, **json.loads(item)}
     config_doc = yaml.load(config_file.read(), Loader=yaml.FullLoader)
-    params = {**config_doc['params'], **json.loads(params)}
+    final_params = {**config_doc['params'], **final_params}
     tags = json.loads(tags)
-    replicas = {**getattr(config_doc, 'replicas', {}), **json.loads(replicas)}
+    replicas = json.loads(replicas)
+    if "replicas" in config_doc:
+        replicas = {**config_doc['replicas'], **replicas}
     secrets = json.loads(secrets)
     service_params = json.loads(service_params)
     if "service_params" in config_doc:
         service_params = merge(config_doc['service_params'], service_params)
-        click.echo(service_params)
     if "secrets" in config_doc:
         secrets = {**config_doc['secrets'], **secrets}
     if "tags" in config_doc:
@@ -53,7 +57,7 @@ def apply_stack_instance(config_file, params, tags, secrets, service_params,
         stack_infrastructure_template=config_doc[
             "stack_infrastructure_template"],
         stack_application_template=config_doc["stack_application_template"],
-        params=params,
+        params=final_params,
         replicas=replicas,
         service_params=service_params,
         secrets=secrets,
@@ -85,7 +89,8 @@ def upload_files(directory, stackl_context):
                     f"Error in stackl document, no 'name' found: {path}")
             try:
                 if stackl_doc["type"] in ["environment", "location", "zone"]:
-                    stackl_context.documents_api.put_document(stackl_doc)
+                    stackl_context.infrastructure_base_api.put_infrastructure_base(
+                        stackl_doc)
                 if stackl_doc["type"] == "functional_requirement":
                     stackl_context.functional_requirements_api.put_functional_requirement(
                         stackl_doc)
